pub enum Error {
CopyFailed(Errno),
PartiallyCopied(usize),
IncompleteMsg {
read: usize,
expected: usize,
},
SystemError(Error),
ReadEof,
UnrecognizedEvent(u8),
UnsupportedIoctls(IoctlFlags),
ZeropageFailed(Errno),
OpenDevUserfaultfd(Error),
}Expand description
Errors for this crate.
Several of these errors contain an underlying Errno value; see
userfaultfd(2) and
ioctl_userfaultfd(2) for more
details on how to interpret these errors.
Variants
CopyFailed(Errno)
Copy ioctl failure with errno value.
PartiallyCopied(usize)
Copy ioctl failure with copied length.
IncompleteMsg
Failure to read a full uffd_msg struct from the underlying file descriptor.
SystemError(Error)
Generic system error.
ReadEof
End-of-file was read from the underlying file descriptor.
UnrecognizedEvent(u8)
An unrecognized event code was found in a uffd_msg struct.
UnsupportedIoctls(IoctlFlags)
Requested ioctls were not available when initializing the API.
ZeropageFailed(Errno)
Zeropage ioctl failure with errno value.
OpenDevUserfaultfd(Error)
Could not open /dev/userfaultfd even though it exists